#ifndef GAP_BUILD_VERSION
#define GAP_BUILD_VERSION  "4.8.3, 19-Mar-2016, build"
#define GAP_BUILD_DATETIME "2016-11-15 06:40:37 (MST)"
#endif
